@@ -1,16 +1,22 @@
 // SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: LGPL-2.1-or-later
 #pragma once
-#include "abstractapplication.h"
+
+#include "merkuro_contact_export.h"
+#include <abstractmerkuroapplication.h>
+
 class QQuickWindow;
-class ContactApplication : public AbstractApplication
+
+class MERKURO_CONTACT_EXPORT ContactApplication : public AbstractMerkuroApplication
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
     explicit ContactApplication(QObject *parent = nullptr);
 
-    QList<KActionCollection *> actionCollections() const override;
+    QList<KirigamiActionCollection *> actionCollections() const override;
 
     Q_INVOKABLE void saveWindowGeometry(QQuickWindow *window);
 
@@ -18,8 +24,9 @@ Q_SIGNALS:
     void createNewContact();
     void createNewContactGroup();
     void refreshAll();
+    void showMenubarChanged(bool state);
 
 private:
     void setupActions() override;
-    KActionCollection *mContactCollection = nullptr;
+    KirigamiActionCollection *mContactCollection = nullptr;
 };
