@@ -7,11 +7,15 @@
 #include <QAbstractListModel>
 #include <qqmlregistration.h>
 
-class EmailModel : public QAbstractListModel
+#include "merkuro_contact_export.h"
+
+class MERKURO_CONTACT_EXPORT EmailModel : public QAbstractListModel
 {
     Q_OBJECT
     QML_ELEMENT
 
+    Q_PROPERTY(QStringList emails READ emails NOTIFY emailsChanged)
+
 public:
     enum ExtraRole {
         TypeRole = Qt::UserRole + 1,
@@ -19,7 +23,12 @@ public:
         DefaultRole,
         EmailRole,
     };
-    enum Type { Unknown = 0, Home = 1, Work = 2, Other = 4 };
+    enum Type {
+        Unknown = 0,
+        Home = 1,
+        Work = 2,
+        Other = 4
+    };
     Q_ENUM(Type)
 
     explicit EmailModel(QObject *parent = nullptr);
@@ -35,7 +44,10 @@ public:
     Q_INVOKABLE void addEmail(const QString &email, EmailModel::Type type);
     Q_INVOKABLE void deleteEmail(int row);
 
+    QStringList emails() const;
+
 Q_SIGNALS:
+    void emailsChanged();
     void changed(const KContacts::Email::List &emails);
 
 private:
