@@ -4,6 +4,7 @@
 #include "../config-merkuro.h"
 #include "messagehandler.h"
 #include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedContext>
 #include <KLocalizedString>
@@ -16,6 +17,10 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
+#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <KLocalizedQmlContext>
+#endif
+
 #define HAVE_KICONTHEME __has_include(<KIconTheme>)
 #if HAVE_KICONTHEME
 #include <KIconTheme>
@@ -72,12 +77,14 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("carl@carlschwan.eu"),
-                        QStringLiteral("https://carlschwan.eu"));
+                        QStringLiteral("https://carlschwan.eu"),
+                        QUrl(QStringLiteral("https://carlschwan.eu/avatar.png")));
     aboutData.addAuthor(i18nc("@info:credit", "Clau Cambra"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("claudio.cambra@gmail.com"),
                         QStringLiteral("https://claudiocambra.com"));
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.merkuro.mail")));
 
     QCommandLineParser parser;
@@ -90,7 +97,11 @@ int main(int argc, char *argv[])
     const auto options = parser.optionNames();
     const auto args = parser.positionalArguments();
     QQmlApplicationEngine engine;
+#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+#else
+    engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
+#endif
     if (!args.isEmpty()) {
         qmlRegisterType<MessageHandler>("org.kde.merkuro.mail.desktop", 1, 0, "MessageHandler");
         QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
